@@ -343,6 +343,8 @@ impl SplinterServiceBuilder {
 pub struct SplinterNodeBuilder {
     node_id: Option<String>,
     endpoints: Option<Vec<String>>,
+    #[cfg(feature = "challenge-authorization")]
+    public_key: Option<Vec<u8>>,
 }
 
 impl SplinterNodeBuilder {
@@ -358,6 +360,11 @@ impl SplinterNodeBuilder {
         self.endpoints.clone()
     }
 
+    #[cfg(feature = "challenge-authorization")]
+    pub fn public_key(&self) -> Option<Vec<u8>> {
+        self.public_key.clone()
+    }
+
     pub fn with_node_id(mut self, node_id: &str) -> SplinterNodeBuilder {
         self.node_id = Some(node_id.into());
         self
@@ -368,6 +375,12 @@ impl SplinterNodeBuilder {
         self
     }
 
+    #[cfg(feature = "challenge-authorization")]
+    pub fn with_public_key(mut self, public_key: &[u8]) -> SplinterNodeBuilder {
+        self.public_key = Some(public_key.into());
+        self
+    }
+
     pub fn build(self) -> Result<SplinterNode, BuilderError> {
         let node_id = self
             .node_id
@@ -377,7 +390,12 @@ impl SplinterNodeBuilder {
             .endpoints
             .ok_or_else(|| BuilderError::MissingField("endpoints".to_string()))?;
 
-        let node = SplinterNode { node_id, endpoints };
+        let node = SplinterNode {
+            node_id,
+            endpoints,
+            #[cfg(feature = "challenge-authorization")]
+            public_key: self.public_key,
+        };
 
         Ok(node)
     }
@@ -407,7 +425,7 @@ mod tests {
     /// Verify that the `CreateCircuitBuilder` works properly and builds a correct `CreateCircuit`
     /// when all fields are set.
     #[test]
-    fn circuit_builder_successful() {
+    fn create_circuit_builder_successful() {
         let mut builder = CreateCircuitBuilder::new();
         assert!(builder.circuit_id().is_none());
         assert!(builder.roster().is_none());
@@ -469,7 +487,7 @@ mod tests {
     /// `authorization_type`, `persistence`, `durability`, `routes`, `application_metadata`, and
     /// `comments` are unset.
     #[test]
-    fn circuit_builder_successful_with_defaults() {
+    fn create_circuit_builder_successful_with_defaults() {
         let service = SplinterServiceBuilder::new()
             .with_service_type("service_type")
             .with_allowed_nodes(&["node_id".into()])
@@ -509,7 +527,7 @@ mod tests {
     /// Verify that the `CreateCircuitBuilder` fails to build when an invalid `circuit_id` is
     /// given.
     #[test]
-    fn circuit_builder_invalid_circuit_id() {
+    fn create_circuit_builder_invalid_circuit_id() {
         let service = SplinterServiceBuilder::new()
             .with_service_type("service_type")
             .with_allowed_nodes(&["node_id".into()])
@@ -563,7 +581,7 @@ mod tests {
 
     /// Verify that the `CreateCircuitBuilder` fails to build when `roster` is not set.
     #[test]
-    fn circuit_builder_unset_roster() {
+    fn create_circuit_builder_unset_roster() {
         let node = SplinterNodeBuilder::new()
             .with_node_id("node_id")
             .with_endpoints(&["endpoint".into()])
@@ -581,7 +599,7 @@ mod tests {
 
     /// Verify that the `CreateCircuitBuilder` fails to build when `members` is not set.
     #[test]
-    fn circuit_builder_unset_members() {
+    fn create_circuit_builder_unset_members() {
         let service = SplinterServiceBuilder::new()
             .with_service_type("service_type")
             .with_allowed_nodes(&["node_id".into()])
@@ -600,7 +618,7 @@ mod tests {
     /// Verify that the `CreateCircuitBuilder` fails to build when `circuit_management_type` is not
     /// set.
     #[test]
-    fn circuit_builder_unset_circuit_management_type() {
+    fn create_circuit_builder_unset_circuit_management_type() {
         let service = SplinterServiceBuilder::new()
             .with_service_type("service_type")
             .with_allowed_nodes(&["node_id".into()])
