@@ -18,7 +18,7 @@ embed_migrations!("./src/migrations/diesel/postgres/migrations");
 
 use diesel::pg::PgConnection;
 
-use crate::migrations::MigrationError;
+use crate::error::InternalError;
 
 /// Run database migrations to create tables defined by biome
 ///
@@ -26,11 +26,8 @@ use crate::migrations::MigrationError;
 ///
 /// * `conn` - Connection to PostgreSQL database
 ///
-pub fn run_migrations(conn: &PgConnection) -> Result<(), MigrationError> {
-    embedded_migrations::run(conn).map_err(|err| MigrationError {
-        context: "Failed to embed migrations".to_string(),
-        source: Box::new(err),
-    })?;
+pub fn run_migrations(conn: &PgConnection) -> Result<(), InternalError> {
+    embedded_migrations::run(conn).map_err(|err| InternalError::from_source(Box::new(err)))?;
 
     info!("Successfully applied PostgreSQL migrations");
 
